/****************************************************************************
** Meta object code from reading C++ file 'komparelistview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kompare-26.04.3/src/komparepart/komparelistview.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'komparelistview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KompareListViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KompareListView::qt_create_metaobjectdata<qt_meta_tag_ZN15KompareListViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KompareListView",
        "differenceClicked",
        "",
        "const KompareDiff2::Difference*",
        "diff",
        "applyDifference",
        "apply",
        "resized",
        "slotSetSelection",
        "const KompareDiff2::DiffModel*",
        "model",
        "setXOffset",
        "x",
        "scrollToId",
        "id",
        "scrollId",
        "slotApplyDifference",
        "slotApplyAllDifferences"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'differenceClicked'
        QtMocHelpers::SignalData<void(const KompareDiff2::Difference *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'applyDifference'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'resized'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetSelection'
        QtMocHelpers::SlotData<void(const KompareDiff2::DiffModel *, const KompareDiff2::Difference *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotSetSelection'
        QtMocHelpers::SlotData<void(const KompareDiff2::Difference *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setXOffset'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'scrollToId'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'scrollId'
        QtMocHelpers::SlotData<int()>(15, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'slotApplyDifference'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'slotApplyAllDifferences'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'slotApplyDifference'
        QtMocHelpers::SlotData<void(const KompareDiff2::Difference *, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KompareListView, qt_meta_tag_ZN15KompareListViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KompareListView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KompareListViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KompareListViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KompareListViewE_t>.metaTypes,
    nullptr
} };

void KompareListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KompareListView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->differenceClicked((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1]))); break;
        case 1: _t->applyDifference((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->resized(); break;
        case 3: _t->slotSetSelection((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::DiffModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[2]))); break;
        case 4: _t->slotSetSelection((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1]))); break;
        case 5: _t->setXOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->scrollToId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: { int _r = _t->scrollId();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->slotApplyDifference((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->slotApplyAllDifferences((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->slotApplyDifference((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KompareListView::*)(const KompareDiff2::Difference * )>(_a, &KompareListView::differenceClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KompareListView::*)(bool )>(_a, &KompareListView::applyDifference, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KompareListView::*)()>(_a, &KompareListView::resized, 2))
            return;
    }
}

const QMetaObject *KompareListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KompareListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KompareListViewE_t>.strings))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int KompareListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KompareListView::differenceClicked(const KompareDiff2::Difference * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KompareListView::applyDifference(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KompareListView::resized()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN20KompareListViewFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto KompareListViewFrame::qt_create_metaobjectdata<qt_meta_tag_ZN20KompareListViewFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KompareListViewFrame",
        "slotSetModel",
        "",
        "const KompareDiff2::DiffModel*",
        "model"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotSetModel'
        QtMocHelpers::SlotData<void(const KompareDiff2::DiffModel *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KompareListViewFrame, qt_meta_tag_ZN20KompareListViewFrameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KompareListViewFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KompareListViewFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KompareListViewFrameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20KompareListViewFrameE_t>.metaTypes,
    nullptr
} };

void KompareListViewFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KompareListViewFrame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotSetModel((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::DiffModel*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KompareListViewFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KompareListViewFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KompareListViewFrameE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int KompareListViewFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN27KompareListViewItemDelegateE_t {};
} // unnamed namespace

template <> constexpr inline auto KompareListViewItemDelegate::qt_create_metaobjectdata<qt_meta_tag_ZN27KompareListViewItemDelegateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KompareListViewItemDelegate"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KompareListViewItemDelegate, qt_meta_tag_ZN27KompareListViewItemDelegateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KompareListViewItemDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<QStyledItemDelegate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27KompareListViewItemDelegateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27KompareListViewItemDelegateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27KompareListViewItemDelegateE_t>.metaTypes,
    nullptr
} };

void KompareListViewItemDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KompareListViewItemDelegate *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KompareListViewItemDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KompareListViewItemDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27KompareListViewItemDelegateE_t>.strings))
        return static_cast<void*>(this);
    return QStyledItemDelegate::qt_metacast(_clname);
}

int KompareListViewItemDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStyledItemDelegate::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
