/****************************************************************************
** Meta object code from reading C++ file 'komparenavtreepart.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kompare-26.04.3/src/komparenavtreepart/komparenavtreepart.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'komparenavtreepart.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18KompareNavTreePartE_t {};
} // unnamed namespace

template <> constexpr inline auto KompareNavTreePart::qt_create_metaobjectdata<qt_meta_tag_ZN18KompareNavTreePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KompareNavTreePart",
        "selectionChanged",
        "",
        "const KompareDiff2::DiffModel*",
        "model",
        "const KompareDiff2::Difference*",
        "diff",
        "slotSetSelection",
        "slotModelsChanged",
        "const KompareDiff2::DiffModelList*",
        "modelList",
        "slotKompareInfo",
        "KompareDiff2::Info*",
        "info",
        "slotSrcDirTreeSelectionChanged",
        "QTreeWidgetItem*",
        "item",
        "slotDestDirTreeSelectionChanged",
        "slotFileListSelectionChanged",
        "slotChangesListSelectionChanged",
        "slotApplyDifference",
        "apply",
        "slotApplyAllDifferences",
        "buildTreeInMemory"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(const KompareDiff2::DiffModel *, const KompareDiff2::Difference *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(const KompareDiff2::Difference *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'slotSetSelection'
        QtMocHelpers::SlotData<void(const KompareDiff2::DiffModel *, const KompareDiff2::Difference *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'slotSetSelection'
        QtMocHelpers::SlotData<void(const KompareDiff2::Difference *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'slotModelsChanged'
        QtMocHelpers::SlotData<void(const KompareDiff2::DiffModelList *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotKompareInfo'
        QtMocHelpers::SlotData<void(KompareDiff2::Info *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotSrcDirTreeSelectionChanged'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotDestDirTreeSelectionChanged'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotFileListSelectionChanged'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotChangesListSelectionChanged'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotApplyDifference'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'slotApplyAllDifferences'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'slotApplyDifference'
        QtMocHelpers::SlotData<void(const KompareDiff2::Difference *, bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'buildTreeInMemory'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KompareNavTreePart, qt_meta_tag_ZN18KompareNavTreePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KompareNavTreePart::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadOnlyPart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KompareNavTreePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KompareNavTreePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18KompareNavTreePartE_t>.metaTypes,
    nullptr
} };

void KompareNavTreePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KompareNavTreePart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::DiffModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[2]))); break;
        case 1: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1]))); break;
        case 2: _t->slotSetSelection((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::DiffModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[2]))); break;
        case 3: _t->slotSetSelection((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1]))); break;
        case 4: _t->slotModelsChanged((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::DiffModelList*>>(_a[1]))); break;
        case 5: _t->slotKompareInfo((*reinterpret_cast<std::add_pointer_t<KompareDiff2::Info*>>(_a[1]))); break;
        case 6: _t->slotSrcDirTreeSelectionChanged((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 7: _t->slotDestDirTreeSelectionChanged((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 8: _t->slotFileListSelectionChanged((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 9: _t->slotChangesListSelectionChanged((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 10: _t->slotApplyDifference((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->slotApplyAllDifferences((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slotApplyDifference((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->buildTreeInMemory(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KompareNavTreePart::*)(const KompareDiff2::DiffModel * , const KompareDiff2::Difference * )>(_a, &KompareNavTreePart::selectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KompareNavTreePart::*)(const KompareDiff2::Difference * )>(_a, &KompareNavTreePart::selectionChanged, 1))
            return;
    }
}

const QMetaObject *KompareNavTreePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KompareNavTreePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KompareNavTreePartE_t>.strings))
        return static_cast<void*>(this);
    return KParts::ReadOnlyPart::qt_metacast(_clname);
}

int KompareNavTreePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadOnlyPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void KompareNavTreePart::selectionChanged(const KompareDiff2::DiffModel * _t1, const KompareDiff2::Difference * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KompareNavTreePart::selectionChanged(const KompareDiff2::Difference * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
