/****************************************************************************
** Meta object code from reading C++ file 'komparesplitter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kompare-26.04.3/src/komparepart/komparesplitter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'komparesplitter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KompareSplitterE_t {};
} // unnamed namespace

template <> constexpr inline auto KompareSplitter::qt_create_metaobjectdata<qt_meta_tag_ZN15KompareSplitterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KompareSplitter",
        "configChanged",
        "",
        "scrollViewsToId",
        "id",
        "setXOffset",
        "x",
        "selectionChanged",
        "const KompareDiff2::Difference*",
        "diff",
        "slotScrollToId",
        "slotDelayedUpdateScrollBars",
        "slotUpdateScrollBars",
        "slotDelayedUpdateVScrollValue",
        "slotUpdateVScrollValue",
        "keyPressEvent",
        "QKeyEvent*",
        "e",
        "slotApplyDifference",
        "apply",
        "slotApplyAllDifferences",
        "slotSetSelection",
        "const KompareDiff2::DiffModel*",
        "model",
        "slotDifferenceClicked",
        "slotConfigChanged",
        "slotDelayedRepaintHandles",
        "slotRepaintHandles",
        "timerTimeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollViewsToId'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'setXOffset'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(const KompareDiff2::Difference *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotScrollToId'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'slotDelayedUpdateScrollBars'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateScrollBars'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDelayedUpdateVScrollValue'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateVScrollValue'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'keyPressEvent'
        QtMocHelpers::SlotData<void(QKeyEvent *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'slotApplyDifference'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'slotApplyAllDifferences'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'slotApplyDifference'
        QtMocHelpers::SlotData<void(const KompareDiff2::Difference *, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'slotSetSelection'
        QtMocHelpers::SlotData<void(const KompareDiff2::DiffModel *, const KompareDiff2::Difference *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotSetSelection'
        QtMocHelpers::SlotData<void(const KompareDiff2::Difference *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotDifferenceClicked'
        QtMocHelpers::SlotData<void(const KompareDiff2::Difference *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotConfigChanged'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDelayedRepaintHandles'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRepaintHandles'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'timerTimeout'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KompareSplitter, qt_meta_tag_ZN15KompareSplitterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KompareSplitter::staticMetaObject = { {
    QMetaObject::SuperData::link<QSplitter::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KompareSplitterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KompareSplitterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KompareSplitterE_t>.metaTypes,
    nullptr
} };

void KompareSplitter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KompareSplitter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: _t->scrollViewsToId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->setXOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1]))); break;
        case 4: _t->slotScrollToId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->slotDelayedUpdateScrollBars(); break;
        case 6: _t->slotUpdateScrollBars(); break;
        case 7: _t->slotDelayedUpdateVScrollValue(); break;
        case 8: _t->slotUpdateVScrollValue(); break;
        case 9: _t->keyPressEvent((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1]))); break;
        case 10: _t->slotApplyDifference((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->slotApplyAllDifferences((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slotApplyDifference((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->slotSetSelection((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::DiffModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[2]))); break;
        case 14: _t->slotSetSelection((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1]))); break;
        case 15: _t->slotDifferenceClicked((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1]))); break;
        case 16: _t->slotConfigChanged(); break;
        case 17: _t->slotDelayedRepaintHandles(); break;
        case 18: _t->slotRepaintHandles(); break;
        case 19: _t->timerTimeout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KompareSplitter::*)()>(_a, &KompareSplitter::configChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KompareSplitter::*)(int )>(_a, &KompareSplitter::scrollViewsToId, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KompareSplitter::*)(int )>(_a, &KompareSplitter::setXOffset, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KompareSplitter::*)(const KompareDiff2::Difference * )>(_a, &KompareSplitter::selectionChanged, 3))
            return;
    }
}

const QMetaObject *KompareSplitter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KompareSplitter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KompareSplitterE_t>.strings))
        return static_cast<void*>(this);
    return QSplitter::qt_metacast(_clname);
}

int KompareSplitter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSplitter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void KompareSplitter::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KompareSplitter::scrollViewsToId(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KompareSplitter::setXOffset(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KompareSplitter::selectionChanged(const KompareDiff2::Difference * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
