/****************************************************************************
** Meta object code from reading C++ file 'kompare_shell.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kompare-26.04.3/src/app/kompare_shell.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kompare_shell.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KompareShellE_t {};
} // unnamed namespace

template <> constexpr inline auto KompareShell::qt_create_metaobjectdata<qt_meta_tag_ZN12KompareShellE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KompareShell",
        "slotUpdateStatusBar",
        "",
        "modelIndex",
        "differenceIndex",
        "modelCount",
        "differenceCount",
        "appliedCount",
        "viewPart",
        "KompareInterface*",
        "slotSetStatusBarText",
        "text",
        "slotFileOpen",
        "slotFileCompareFiles",
        "slotFileBlendURLAndDiff",
        "slotShowTextView",
        "slotFileClose",
        "optionsConfigureKeys",
        "optionsConfigureToolbars",
        "slotSetDiffString",
        "diffString",
        "newToolbarConfig",
        "slotVisibilityChanged",
        "visible"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotUpdateStatusBar'
        QtMocHelpers::SlotData<void(int, int, int, int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
            { QMetaType::Int, 7 },
        }}),
        // Slot 'viewPart'
        QtMocHelpers::SlotData<KompareInterface *() const>(8, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'slotSetStatusBarText'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'slotFileOpen'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFileCompareFiles'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFileBlendURLAndDiff'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowTextView'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFileClose'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'optionsConfigureKeys'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'optionsConfigureToolbars'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetDiffString'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'newToolbarConfig'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotVisibilityChanged'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KompareShell, qt_meta_tag_ZN12KompareShellE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KompareShell::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::MainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KompareShellE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KompareShellE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KompareShellE_t>.metaTypes,
    nullptr
} };

void KompareShell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KompareShell *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotUpdateStatusBar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 1: { KompareInterface* _r = _t->viewPart();
            if (_a[0]) *reinterpret_cast<KompareInterface**>(_a[0]) = std::move(_r); }  break;
        case 2: _t->slotSetStatusBarText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->slotFileOpen(); break;
        case 4: _t->slotFileCompareFiles(); break;
        case 5: _t->slotFileBlendURLAndDiff(); break;
        case 6: _t->slotShowTextView(); break;
        case 7: _t->slotFileClose(); break;
        case 8: _t->optionsConfigureKeys(); break;
        case 9: _t->optionsConfigureToolbars(); break;
        case 10: _t->slotSetDiffString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->newToolbarConfig(); break;
        case 12: _t->slotVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KompareShell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KompareShell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KompareShellE_t>.strings))
        return static_cast<void*>(this);
    return KParts::MainWindow::qt_metacast(_clname);
}

int KompareShell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::MainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
