/****************************************************************************
** Meta object code from reading C++ file 'kompare_part.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kompare-26.04.3/src/komparepart/kompare_part.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kompare_part.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KomparePartE_t {};
} // unnamed namespace

template <> constexpr inline auto KomparePart::qt_create_metaobjectdata<qt_meta_tag_ZN11KomparePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KomparePart",
        "modelsChanged",
        "",
        "const KompareDiff2::DiffModelList*",
        "models",
        "setSelection",
        "const KompareDiff2::DiffModel*",
        "model",
        "const KompareDiff2::Difference*",
        "diff",
        "selectionChanged",
        "applyDifference",
        "apply",
        "applyAllDifferences",
        "configChanged",
        "differenceClicked",
        "lineNumber",
        "appliedChanged",
        "diffURLChanged",
        "kompareInfo",
        "KompareDiff2::Info*",
        "info",
        "setStatusBarModelInfo",
        "modelIndex",
        "differenceIndex",
        "modelCount",
        "differenceCount",
        "appliedCount",
        "diffString",
        "saveAll",
        "saveDiff",
        "slotFilePrint",
        "slotFilePrintPreview",
        "slotSetStatus",
        "KompareDiff2::Status",
        "status",
        "slotShowError",
        "error",
        "slotSwap",
        "slotShowDiffstats",
        "slotRefreshDiff",
        "optionsPreferences",
        "updateActions",
        "updateCaption",
        "updateStatus",
        "compareAndUpdateAll",
        "slotPaintRequested",
        "QPrinter*",
        "onContextMenuRequested",
        "QPoint",
        "pos"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modelsChanged'
        QtMocHelpers::SignalData<void(const KompareDiff2::DiffModelList *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'setSelection'
        QtMocHelpers::SignalData<void(const KompareDiff2::DiffModel *, const KompareDiff2::Difference *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'setSelection'
        QtMocHelpers::SignalData<void(const KompareDiff2::Difference *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(const KompareDiff2::DiffModel *, const KompareDiff2::Difference *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(const KompareDiff2::Difference *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'applyDifference'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'applyAllDifferences'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'applyDifference'
        QtMocHelpers::SignalData<void(const KompareDiff2::Difference *, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { QMetaType::Bool, 12 },
        }}),
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'differenceClicked'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'appliedChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'diffURLChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kompareInfo'
        QtMocHelpers::SignalData<void(KompareDiff2::Info *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'setStatusBarModelInfo'
        QtMocHelpers::SignalData<void(int, int, int, int, int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { QMetaType::Int, 26 },
            { QMetaType::Int, 27 },
        }}),
        // Signal 'diffString'
        QtMocHelpers::SignalData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'saveAll'
        QtMocHelpers::SlotData<bool()>(29, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'saveDiff'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFilePrint'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFilePrintPreview'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetStatus'
        QtMocHelpers::SlotData<void(KompareDiff2::Status)>(33, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'slotShowError'
        QtMocHelpers::SlotData<void(const QString &)>(36, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'slotSwap'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotShowDiffstats'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRefreshDiff'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'optionsPreferences'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateActions'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateCaption'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateStatus'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'compareAndUpdateAll'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotPaintRequested'
        QtMocHelpers::SlotData<void(QPrinter *)>(46, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 47, 2 },
        }}),
        // Slot 'onContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KomparePart, qt_meta_tag_ZN11KomparePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KomparePart::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadWritePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KomparePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KomparePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KomparePartE_t>.metaTypes,
    nullptr
} };

void KomparePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KomparePart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modelsChanged((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::DiffModelList*>>(_a[1]))); break;
        case 1: _t->setSelection((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::DiffModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[2]))); break;
        case 2: _t->setSelection((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1]))); break;
        case 3: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::DiffModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[2]))); break;
        case 4: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1]))); break;
        case 5: _t->applyDifference((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->applyAllDifferences((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->applyDifference((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->configChanged(); break;
        case 9: _t->differenceClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->appliedChanged(); break;
        case 11: _t->diffURLChanged(); break;
        case 12: _t->kompareInfo((*reinterpret_cast<std::add_pointer_t<KompareDiff2::Info*>>(_a[1]))); break;
        case 13: _t->setStatusBarModelInfo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 14: _t->diffString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: { bool _r = _t->saveAll();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->saveDiff(); break;
        case 17: _t->slotFilePrint(); break;
        case 18: _t->slotFilePrintPreview(); break;
        case 19: _t->slotSetStatus((*reinterpret_cast<std::add_pointer_t<KompareDiff2::Status>>(_a[1]))); break;
        case 20: _t->slotShowError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->slotSwap(); break;
        case 22: _t->slotShowDiffstats(); break;
        case 23: _t->slotRefreshDiff(); break;
        case 24: _t->optionsPreferences(); break;
        case 25: _t->updateActions(); break;
        case 26: _t->updateCaption(); break;
        case 27: _t->updateStatus(); break;
        case 28: _t->compareAndUpdateAll(); break;
        case 29: _t->slotPaintRequested((*reinterpret_cast<std::add_pointer_t<QPrinter*>>(_a[1]))); break;
        case 30: _t->onContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(const KompareDiff2::DiffModelList * )>(_a, &KomparePart::modelsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(const KompareDiff2::DiffModel * , const KompareDiff2::Difference * )>(_a, &KomparePart::setSelection, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(const KompareDiff2::Difference * )>(_a, &KomparePart::setSelection, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(const KompareDiff2::DiffModel * , const KompareDiff2::Difference * )>(_a, &KomparePart::selectionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(const KompareDiff2::Difference * )>(_a, &KomparePart::selectionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(bool )>(_a, &KomparePart::applyDifference, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(bool )>(_a, &KomparePart::applyAllDifferences, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(const KompareDiff2::Difference * , bool )>(_a, &KomparePart::applyDifference, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)()>(_a, &KomparePart::configChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(int )>(_a, &KomparePart::differenceClicked, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)()>(_a, &KomparePart::appliedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)()>(_a, &KomparePart::diffURLChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(KompareDiff2::Info * )>(_a, &KomparePart::kompareInfo, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(int , int , int , int , int )>(_a, &KomparePart::setStatusBarModelInfo, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KomparePart::*)(const QString & )>(_a, &KomparePart::diffString, 14))
            return;
    }
}

const QMetaObject *KomparePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KomparePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KomparePartE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KompareInterface"))
        return static_cast< KompareInterface*>(this);
    if (!strcmp(_clname, "com.kde.Kompare.KompareInterface/4.0"))
        return static_cast< KompareInterface*>(this);
    return KParts::ReadWritePart::qt_metacast(_clname);
}

int KomparePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadWritePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void KomparePart::modelsChanged(const KompareDiff2::DiffModelList * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KomparePart::setSelection(const KompareDiff2::DiffModel * _t1, const KompareDiff2::Difference * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KomparePart::setSelection(const KompareDiff2::Difference * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KomparePart::selectionChanged(const KompareDiff2::DiffModel * _t1, const KompareDiff2::Difference * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KomparePart::selectionChanged(const KompareDiff2::Difference * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KomparePart::applyDifference(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KomparePart::applyAllDifferences(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KomparePart::applyDifference(const KompareDiff2::Difference * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void KomparePart::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KomparePart::differenceClicked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KomparePart::appliedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KomparePart::diffURLChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KomparePart::kompareInfo(KompareDiff2::Info * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void KomparePart::setStatusBarModelInfo(int _t1, int _t2, int _t3, int _t4, int _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 14
void KomparePart::diffString(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
