/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // komparepartui.rc
  0x0,0x0,0x1,0x75,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x5d,0x6,0x5d,0xb,0x0,0xb2,0xcd,0x2a,0x19,0x40,0xd7,0x3,
  0xff,0x53,0x9a,0xf8,0xc7,0x71,0x90,0x88,0x6,0x6c,0x1d,0x91,0xd3,0xb3,0xbf,0xa2,
  0x13,0xae,0x2a,0x85,0x57,0x4,0x0,0x52,0x3f,0x6d,0x62,0xa,0xdf,0x88,0xa0,0xb3,
  0xbb,0x77,0xa2,0x9f,0x3f,0xad,0x66,0xf6,0x5e,0x96,0xc6,0x57,0xd2,0x9a,0xad,0x7b,
  0xbf,0xde,0xe2,0x5b,0xfd,0xdd,0xb1,0xc3,0xd8,0xed,0x67,0x31,0x97,0xfd,0xfc,0x4,
  0xd,0xbf,0x82,0x3f,0xb7,0xad,0x19,0xeb,0xed,0x5b,0x63,0xf,0x37,0xfd,0x39,0xfb,
  0x9c,0xef,0xf6,0xec,0xf8,0xa5,0x2c,0xab,0x98,0xee,0x3a,0xb7,0x88,0xf9,0xa0,0x6b,
  0xeb,0x4a,0x8,0xea,0x18,0xd8,0x73,0x1,0xd9,0xe2,0x6f,0xda,0xd5,0x4c,0x4a,0x0,
  0xc9,0xae,0x7c,0xf6,0x1f,0x5b,0xdd,0xbb,0xcc,0xf6,0x4e,0x5b,0xcf,0x5b,0xce,0x62,
  0x1e,0xf6,0x56,0x9d,0x1f,0x94,0xd3,0x7a,0xef,0x72,0xf3,0x78,0xcf,0x2d,0x5,0x90,
  0x89,0x6d,0x6c,0xd8,0xd9,0x31,0x37,0xe5,0xd3,0x4c,0x52,0x25,0xc9,0xfa,0x69,0xb2,
  0x89,0xaa,0x69,0x81,0x98,0x80,0x6,0x51,0xa0,0x51,0x12,0x33,0x43,0x33,0x5b,0x98,
  0xad,0x3,0x20,0x42,0xa3,0x2c,0xd3,0x6d,0x4b,0x65,0xf3,0x8d,0xd8,0xd4,0x93,0x0,
  0x45,0x25,0x23,0xd3,0xaf,0x32,0xc3,0x3a,0xa7,0x67,0x4e,0xd0,0x44,0x83,0xd9,0xd8,
  0xa0,0x46,0x6e,0x6,0xd0,0xa4,0x91,0x9c,0x2f,0x3f,0x96,0x89,0x89,0xc6,0x10,0x99,
  0x77,0xbc,0xf9,0x88,0xfa,0xa5,0xd4,0x53,0x77,0x71,0x73,0x6d,0x1d,0x58,0x2d,0xb9,
  0x5b,0xf3,0xbc,0x24,0xc4,0x42,0x8d,0x1d,0x9c,0x2b,0x54,0x39,0xb2,0x86,0xc9,0x3c,
  0x8f,0x3b,0xc5,0xb8,0x56,0x1f,0x2c,0x93,0xf5,0x3,0xd6,0x83,0xf8,0xc1,0xd4,0xaf,
  0x27,0xa0,0xf5,0xc8,0x19,0x7a,0xc4,0x10,0x5e,0xc4,0x67,0x69,0xaa,0x9a,0xc8,0xb4,
  0x22,0x20,0x76,0x12,0x1c,0x45,0xc3,0x58,0x3b,0x88,0x0,0x19,0x36,0x51,0x5f,0x1b,
  0x5c,0x99,0x68,0xc8,0x83,0xb1,0x16,0x48,0x8c,0x9d,0x67,0xad,0x14,0x38,0x33,0x8c,
  0x45,0x7c,0x4b,0x23,0xab,0xd8,0x70,0x70,0x89,0x98,0x6,0x23,0x5,0xbe,0x8,0x20,
  0x71,0xe2,0xbb,0x15,0x97,0x81,0xd0,0x22,0x3,0x28,0x81,0x81,0x3,0xcc,0x6f,0x80,
  0x4e,0x40,0xa9,0x2,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // komparepart
  0x0,0xb,
  0x8,0x68,0xa0,0x54,
  0x0,0x6b,
  0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x61,0x0,0x72,0x0,0x65,0x0,0x70,0x0,0x61,0x0,0x72,0x0,0x74,
    // komparepartui.rc
  0x0,0x10,
  0x4,0xb6,0xd1,0x83,
  0x0,0x6b,
  0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x61,0x0,0x72,0x0,0x65,0x0,0x70,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0x19,0x36,0x45,0x98,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0x19,0x36,0x45,0x98,
  // :/kxmlgui5/komparepart
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0x19,0x36,0x45,0x98,
  // :/kxmlgui5/komparepart/komparepartui.rc
  0x0,0x0,0x0,0x32,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0x19,0x36,0x45,0x98,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kompare_part)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kompare_part)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kompare_part)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kompare_part)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kompare_part)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kompare_part)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
